==> 0.0.1-31.tar.gz: secant-ios-wallet/secantTests/WalletEventsTests/WalletEventsTests.swift <==
//
//  WalletEventsTests.swift
//  secantTests
//
//  Created by Lukáš Korba on 27.04.2022.
//

import XCTest
@testable import secant_testnet
import ComposableArchitecture

class WalletEventsTests: XCTestCase {
    static let testScheduler = DispatchQueue.test
    
    let testEnvironment = WalletEventsFlowEnvironment(
        pasteboard: .test,
        scheduler: testScheduler.eraseToAnyScheduler(),
        SDKSynchronizer: TestWrappedSDKSynchronizer(),
        zcashSDKEnvironment: .testnet
    )
    
    func testSynchronizerSubscription() throws {
        let store = TestStore(
            initialState: WalletEventsFlowState(
                route: .latest,
                isScrollable: true,
                walletEvents: []
            ),
            reducer: WalletEventsFlowReducer.default,
            environment: testEnvironment
        )
        
        store.send(.onAppear)

        store.receive(.synchronizerStateChanged(.unknown))

        // ending the subscription
        store.send(.onDisappear)
    }

    func testSynchronizerStateChanged2Synced() throws {
        let mocked: [TransactionStateMockHelper] = [
            TransactionStateMockHelper(date: 1651039202, amount: Zatoshi(amount: 1), status: .paid(success: false), uuid: "aa11"),
            TransactionStateMockHelper(date: 1651039101, amount: Zatoshi(amount: 2), uuid: "bb22"),
            TransactionStateMockHelper(date: 1651039000, amount: Zatoshi(amount: 3), status: .paid(success: true), uuid: "cc33"),
            TransactionStateMockHelper(date: 1651039505, amount: Zatoshi(amount: 4), uuid: "dd44"),
            TransactionStateMockHelper(date: 1651039404, amount: Zatoshi(amount: 5), uuid: "ee55"),
            TransactionStateMockHelper(
                date: 1651039606,
                amount: Zatoshi(amount: 6),
                status: .paid(success: false),
                uuid: "ff66"
            ),
            TransactionStateMockHelper(date: 1651039303, amount: Zatoshi(amount: 7), uuid: "gg77"),
            TransactionStateMockHelper(date: 1651039707, amount: Zatoshi(amount: 8), status: .paid(success: true), uuid: "hh88"),
            TransactionStateMockHelper(date: 1651039808, amount: Zatoshi(amount: 9), uuid: "ii99")
        ]

        let walletEvents: [WalletEvent] = mocked.map {
            let transaction = TransactionState.placeholder(
                amount: $0.amount,
                fee: Zatoshi(amount: 10),
                shielded: $0.shielded,
                status: $0.amount.amount > 5 ? .pending : $0.status,
                timestamp: $0.date,
                uuid: $0.uuid
            )
            return WalletEvent(
                id: transaction.id,
                state: transaction.status == .pending ? .pending(transaction) : .send(transaction),
                timestamp: transaction.timestamp
            )
        }

        let identifiedWalletEvents = IdentifiedArrayOf(uniqueElements: walletEvents)
        
        let store = TestStore(
            initialState: WalletEventsFlowState(
                route: .latest,
                isScrollable: true,
                walletEvents: identifiedWalletEvents
            ),
            reducer: WalletEventsFlowReducer.default,
            environment: testEnvironment
        )
        
        store.send(.synchronizerStateChanged(.synced))
        
        Self.testScheduler.advance(by: 0.01)

        store.receive(.updateWalletEvents(walletEvents)) { state in
            let receivedWalletEvents = IdentifiedArrayOf(
                uniqueElements:
                    walletEvents
                    .sorted(by: { lhs, rhs in
                        lhs.timestamp > rhs.timestamp
                    })
            )
            
            state.walletEvents = receivedWalletEvents
        }
    }
    
    func testCopyToPasteboard() throws {
        let pasteboard = WrappedPasteboard.test
        
        let testEnvironment = WalletEventsFlowEnvironment(
            pasteboard: pasteboard,
            scheduler: DispatchQueue.test.eraseToAnyScheduler(),
            SDKSynchronizer: TestWrappedSDKSynchronizer(),
            zcashSDKEnvironment: .testnet
        )
        
        let store = TestStore(
            initialState: WalletEventsFlowState(
                route: .latest,
                isScrollable: true,
                walletEvents: []
            ),
            reducer: WalletEventsFlowReducer.default,
            environment: testEnvironment
        )

        let testText = "test text"
        store.send(.copyToPastboard(testText))
        
        XCTAssertEqual(pasteboard.getString(), testText, "WalletEvetns: `testCopyToPasteboard` is expected to match the input `\(testText)`")
    }
}

==> 0.0.1-33.tar.gz: secant-ios-wallet/secantTests/WalletEventsTests/WalletEventsTests.swift <==
//
//  WalletEventsTests.swift
//  secantTests
//
//  Created by Lukáš Korba on 27.04.2022.
//

import XCTest
@testable import secant_testnet
import ComposableArchitecture

class WalletEventsTests: XCTestCase {
    static let testScheduler = DispatchQueue.test
    
    let testEnvironment = WalletEventsFlowEnvironment(
        pasteboard: .test,
        scheduler: testScheduler.eraseToAnyScheduler(),
        SDKSynchronizer: TestWrappedSDKSynchronizer(),
        zcashSDKEnvironment: .testnet
    )
    
    func testSynchronizerSubscription() throws {
        let store = TestStore(
            initialState: WalletEventsFlowState(
                route: .latest,
                isScrollable: true,
                walletEvents: []
            ),
            reducer: WalletEventsFlowReducer.default,
            environment: testEnvironment
        )
        
        store.send(.onAppear) { state in
            state.requiredTransactionConfirmations = 10
        }

        store.receive(.synchronizerStateChanged(.unknown))

        // ending the subscription
        store.send(.onDisappear)
    }

    func testSynchronizerStateChanged2Synced() throws {
        let mocked: [TransactionStateMockHelper] = [
            TransactionStateMockHelper(date: 1651039202, amount: Zatoshi(amount: 1), status: .paid(success: false), uuid: "aa11"),
            TransactionStateMockHelper(date: 1651039101, amount: Zatoshi(amount: 2), uuid: "bb22"),
            TransactionStateMockHelper(date: 1651039000, amount: Zatoshi(amount: 3), status: .paid(success: true), uuid: "cc33"),
            TransactionStateMockHelper(date: 1651039505, amount: Zatoshi(amount: 4), uuid: "dd44"),
            TransactionStateMockHelper(date: 1651039404, amount: Zatoshi(amount: 5), uuid: "ee55"),
            TransactionStateMockHelper(
                date: 1651039606,
                amount: Zatoshi(amount: 6),
                status: .paid(success: false),
                uuid: "ff66"
            ),
            TransactionStateMockHelper(date: 1651039303, amount: Zatoshi(amount: 7), uuid: "gg77"),
            TransactionStateMockHelper(date: 1651039707, amount: Zatoshi(amount: 8), status: .paid(success: true), uuid: "hh88"),
            TransactionStateMockHelper(date: 1651039808, amount: Zatoshi(amount: 9), uuid: "ii99")
        ]

        let walletEvents: [WalletEvent] = mocked.map {
            let transaction = TransactionState.placeholder(
                amount: $0.amount,
                fee: Zatoshi(amount: 10),
                shielded: $0.shielded,
                status: $0.amount.amount > 5 ? .pending : $0.status,
                timestamp: $0.date,
                uuid: $0.uuid
            )
            return WalletEvent(
                id: transaction.id,
                state: transaction.status == .pending ? .pending(transaction) : .send(transaction),
                timestamp: transaction.timestamp
            )
        }

        let identifiedWalletEvents = IdentifiedArrayOf(uniqueElements: walletEvents)
        
        let store = TestStore(
            initialState: WalletEventsFlowState(
                route: .latest,
                isScrollable: true,
                walletEvents: identifiedWalletEvents
            ),
            reducer: WalletEventsFlowReducer.default,
            environment: testEnvironment
        )
        
        store.send(.synchronizerStateChanged(.synced))
        
        Self.testScheduler.advance(by: 0.01)

        store.receive(.updateWalletEvents(walletEvents)) { state in
            let receivedWalletEvents = IdentifiedArrayOf(
                uniqueElements:
                    walletEvents
                    .sorted(by: { lhs, rhs in
                        lhs.timestamp > rhs.timestamp
                    })
            )
            
            state.walletEvents = receivedWalletEvents
        }
    }
    
    func testCopyToPasteboard() throws {
        let pasteboard = WrappedPasteboard.test
        
        let testEnvironment = WalletEventsFlowEnvironment(
            pasteboard: pasteboard,
            scheduler: DispatchQueue.test.eraseToAnyScheduler(),
            SDKSynchronizer: TestWrappedSDKSynchronizer(),
            zcashSDKEnvironment: .testnet
        )
        
        let store = TestStore(
            initialState: WalletEventsFlowState(
                route: .latest,
                isScrollable: true,
                walletEvents: []
            ),
            reducer: WalletEventsFlowReducer.default,
            environment: testEnvironment
        )

        let testText = "test text"
        store.send(.copyToPastboard(testText))
        
        XCTAssertEqual(pasteboard.getString(), testText, "WalletEvetns: `testCopyToPasteboard` is expected to match the input `\(testText)`")
    }
}
